
/* Name of package.  */
#undef PACKAGE

/* Version of package.  */
#undef VERSION

/* Linux */
#undef _BSD_SOURCE

/* Linux */
#undef HAVE_FEATURES_H

/* BSD socket */
#undef HAVE_SOCK_SIN_LEN

/* MYSQL */
#undef HAVE_MYSQL

/* PGSQL */
#undef HAVE_PGSQL

/* DEC */
#undef HAVE_LL_STRTOUL

/* OPENSSL */
#undef HAVE_OPENSSL

